@@ -897,7 +897,7 @@ bool KviPackageReader::unpackFile(KviFile * pFile,const TQString &szUnpackPath)
 						return writeError();
 					}
 				} /* else { THIS HAPPENS FOR ZERO SIZE FILES
-					debug("hum.... internal, rEWq (ret = %d) (avail_out = %d)",ret,zstr.avail_out);
+					tqDebug("hum.... internal, rEWq (ret = %d) (avail_out = %d)",ret,zstr.avail_out);
 					
 					inflateEnd(&zstr);
 					setLastError(__tr2qs("Compression library internal error"));
