@@ -532,7 +532,7 @@ bool KviHttpRequest::processHeader(KviStr &szHeader)
 			s->cutLeft(idx + 1);
 			s->stripWhiteSpace();
 			hdr.replace(szName.ptr(),new KviStr(*s));
-			//debug("FOUND HEADER (%s)=(%s)",szName.ptr(),s->ptr());
+			//tqDebug("FOUND HEADER (%s)=(%s)",szName.ptr(),s->ptr());
 		}
 	}
 
@@ -914,7 +914,7 @@ bool KviHttpRequestThread::processInternalEvents()
 			}
 			break;
 			default:
-				debug("Unrecognized event in http thread");
+				tqDebug("Unrecognized event in http thread");
 				delete e;
 				return false;
 			break;
@@ -1425,7 +1425,7 @@ void KviHttpRequestThread::runInternal()
 		szRequest += "\r\n";
 	}
 
-	//debug("SENDING REQUEST:\n%s",szRequest.ptr());
+	//tqDebug("SENDING REQUEST:\n%s",szRequest.ptr());
 
 	if(!sendBuffer(szRequest.ptr(),szRequest.len(),60))return;
 
