@@ -1206,7 +1206,7 @@ bool kvi_getInterfaceAddress(const char * ifname,TQString &buffer)
 
 {
 
-	debug("kvi_getInterfaceAddress is deprecated: use KviNetUtils::getInterfaceAddress");
+	tqDebug("kvi_getInterfaceAddress is deprecated: use KviNetUtils::getInterfaceAddress");
 
 	TQString szRet;
 
