@@ -218,7 +218,7 @@
 	    init();
 	    if (myType == RadioButton) {
 	        if (parent->type() != RadioButtonController)
-	            qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	            tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	                      "child of a controller");
 	        else
 	            d->exclusive = parent;
@@ -233,7 +233,7 @@
 	    init();
 	    if (myType == RadioButton) {
 	        if (parent->type() != RadioButtonController)
-	            qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	            tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	                      "child of a controller");
 	        else
 	            d->exclusive = parent;
@@ -246,7 +246,7 @@
 	{
 	    myType = tt;
 	    if (myType == RadioButton) {
-	      qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	      tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	               "child of a KviTalCheckListItem");
 	    }
 	    init();
@@ -258,7 +258,7 @@
 	{
 	    myType = tt;
 	    if (myType == RadioButton) {
-	        qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	        tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	                  "child of a KviTalCheckListItem");
 	    }
 	    init();
@@ -270,7 +270,7 @@
 	{
 	    myType = tt;
 	    if (tt == RadioButton)
-	        qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	        tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	                 "child of a KviTalCheckListItem");
 	    init();
 	}
@@ -281,7 +281,7 @@
 	{
 	    myType = tt;
 	    if (tt == RadioButton)
-	        qWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	        tqWarning("KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	                  "child of a KviTalCheckListItem");
 	    init();
 	}
@@ -332,7 +332,7 @@
 	void KviTalCheckListItem::setTristate(bool b)
 	{
 	    if ((myType != CheckBoxController) && (myType != CheckBox)) {
-	        qWarning("KviTalCheckListItem::setTristate(), has no effect on RadioButton "
+	        tqWarning("KviTalCheckListItem::setTristate(), has no effect on RadioButton "
 	                  "or RadioButtonController.");
 	        return;
 	    }
@@ -943,7 +943,7 @@
 	    init();
 	    if ( myType == RadioButton ) {
 		if ( parent->type() != RadioButtonController )
-		    qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+		    tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 			      "child of a controller" );
 		else
 		    d->exclusive = parent;
@@ -958,7 +958,7 @@
 	    init();
 	    if ( myType == RadioButton ) {
 	 	if ( parent->type() != RadioButtonController )
-	 	    qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	 	    tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 			      "child of a controller" );
 	 	else
 	 	    d->exclusive = parent;
@@ -971,7 +971,7 @@
 	{
 	    myType = tt;
 	    if ( myType == RadioButton ) {
-	      qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	      tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 		       "child of a KviTalCheckListItem" );
 	    }
 	    init();
@@ -983,7 +983,7 @@
 	{
 	    myType = tt;
 	    if ( myType == RadioButton ) {
-	 	qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	 	tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	 		  "child of a KviTalCheckListItem" );
 	    }
 	    init();
@@ -995,7 +995,7 @@
 	{
 	    myType = tt;
 	    if ( tt == RadioButton )
-		qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+		tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 			 "child of a KviTalCheckListItem" );
 	    init();
 	}
@@ -1006,7 +1006,7 @@
 	{
 	    myType = tt;
 	    if ( tt == RadioButton )
-	 	qWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
+	 	tqWarning( "KviTalCheckListItem::KviTalCheckListItem(), radio button must be "
 	 		  "child of a KviTalCheckListItem" );
 	    init();
 	}
@@ -1066,7 +1066,7 @@
 	void KviTalCheckListItem::setTristate( bool b )
 	{
 	    if ( ( myType != CheckBoxController ) && ( myType != CheckBox ) ) {
-		qWarning( "KviTalCheckListItem::setTristate(), has no effect on RadioButton "
+		tqWarning( "KviTalCheckListItem::setTristate(), has no effect on RadioButton "
 			  "or RadioButtonController." );
 	    	return;
 	    }
