@@ -302,9 +302,9 @@ void KviChannel::saveProperties(KviConfig *cfg)
 	cfg->writeEntry("TopSplitter",m_pTopSplitter->sizes());
 	cfg->writeEntry("Splitter",m_pSplitter->sizes());
 #ifdef COMPILE_USE_QT4
-	TQList<int> tmp = m_pVertSplitter->sizes();
+	TQPtrList<int> tmp = m_pVertSplitter->sizes();
 	KviValueList<int> tmp2;
-	for(TQList<int>::Iterator it = tmp.begin();it != tmp.end();++it)
+	for(TQPtrList<int>::Iterator it = tmp.begin();it != tmp.end();++it)
 		tmp2.append(*it);
 	cfg->writeEntry("VertSplitter",m_pMessageView ? tmp2 : m_VertSplitterSizesList);
 #else
