@@ -171,8 +171,8 @@ void KviCustomToolBar::beginCustomize()
 	m_pFilteredChildren->setAutoDelete(true);
 	// filter the events for all the children
 #ifdef COMPILE_USE_QT4
-	TQList<TQObject*> l = children();
-	for(TQList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
+	TQPtrList<TQObject*> l = children();
+	for(TQPtrList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
 	{
 		if((*it)->isWidgetType())
 			filterChild(*it);
@@ -193,8 +193,8 @@ void KviCustomToolBar::endCustomize()
 {
 	// stop filtering events
 #ifdef COMPILE_USE_QT4
-	TQList<TQObject*> l = children();
-	for(TQList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
+	TQPtrList<TQObject*> l = children();
+	for(TQPtrList<TQObject*>::Iterator it = l.begin();it != l.end();++it)
 	{
 		if((*it)->isWidgetType())
 			unfilterChild(*it);
