@@ -77,16 +77,7 @@
 #define ACCEL_KEY(k) "\t" + TQString(TQKeySequence( TQt::CTRL | TQt::Key_ ## k ))
 #endif
 
-// FIXME: #warning "This hack is temporary...later remove it"
-#ifndef TQT_CLEAN_NAMESPACE
-	#define TQT_CLEAN_NAMESPACE
-	#include <tqcursor.h>
-	#undef TQT_CLEAN_NAMESPACE
-#else
-	#include <tqcursor.h>
-#endif
-
-
+#include <tqcursor.h>
 
 //This comes from kvi_app.cpp
 extern KviColorWindow    * g_pColorWindow;
