@@ -786,7 +786,7 @@ KviCahnnelListSelector::~KviCahnnelListSelector()
 void KviCahnnelListSelector::commit()
 {
 	m_pOption->clear();
-	register KviChanListViewItem* pItem;
+	KviChanListViewItem* pItem;
 	KviTalListViewItemIterator it( m_pListView);
 	while ( it.current() ) {
 		pItem = (KviChanListViewItem*)( it.current() );
