@@ -166,7 +166,7 @@ void KviStatusBar::load()
 			if (a)
 				a->loadState(prefix.ptr(),&cfg);
 			else
-				debug("warning: failed to create applet %s (preload: %s)!",
+				tqDebug("warning: failed to create applet %s (preload: %s)!",
 					szInternalName.utf8().data(), szPreloadModule.utf8().data());
 		}
 	}
