@@ -1006,8 +1006,8 @@ void KviWindow::focusInEvent(TQFocusEvent *)
 		if(m_pIrcView)m_pFocusHandler = m_pIrcView;
 		else {
 #ifdef COMPILE_USE_QT4
-			TQList<TQObject *> list = children();
-			for(TQList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
+			TQPtrList<TQObject *> list = children();
+			for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
 			{
 				TQObject * c = *it;
 				if(c->isWidgetType())
@@ -1124,8 +1124,8 @@ void KviWindow::childInserted(TQWidget * o)
 	}
 
 #ifdef COMPILE_USE_QT4
-	TQList<TQObject *> list = o->children();
-	for(TQList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
+	TQPtrList<TQObject *> list = o->children();
+	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
 	{
 		TQObject * c = *it;
 		if(c->isWidgetType())
@@ -1162,8 +1162,8 @@ void KviWindow::childRemoved(TQWidget * o)
 		m_pLastFocusedChild = 0;
 
 #ifdef COMPILE_USE_QT4
-	TQList<TQObject *> list = o->children();
-	for(TQList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
+	TQPtrList<TQObject *> list = o->children();
+	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
 	{
 		TQObject * c = *it;
 		if(c->isWidgetType())
@@ -1217,11 +1217,11 @@ void KviWindow::updateBackgrounds(TQObject * obj)
 	if(!obj)
 		obj = TQT_TQOBJECT(this);
 #ifdef COMPILE_USE_QT4
-	TQList<TQObject *> list = obj->children();
+	TQPtrList<TQObject *> list = obj->children();
 	if (list.count())
 	{
 	
-	for(TQList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
+	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
 	{
 		TQObject * child = *it;
 		if(child->metaObject()->indexOfProperty("TransparencyCapable") != -1){
