@@ -90,7 +90,7 @@ KviCanvasPolygon::KviCanvasPolygon(TQCanvas * c,int x,int y,TQPointArray &pnts,d
 	m_properties.insert("uLineWidth",TQVariant((unsigned int)0));
 
 	m_properties.insert("clrBackground",TQVariant(TQColor(0,0,0)));
-	m_properties.insert("bHasBackground",TQVariant(false,1));
+	m_properties.insert("bHasBackground",TQVariant(false));
 
 	m_dScaleFactor = dScaleFactor;
 	m_points = pnts;
@@ -193,7 +193,7 @@ KviCanvasEllipticItem::KviCanvasEllipticItem(TQCanvas * c,int x,int y,int w,int
 	m_properties.insert("uLineWidth",TQVariant((unsigned int)0));
 
 	m_properties.insert("clrBackground",TQVariant(TQColor(0,0,0)));
-	m_properties.insert("bHasBackground",TQVariant(false,1));
+	m_properties.insert("bHasBackground",TQVariant(false));
 
 //	m_properties.insert("iStartAngle",TQVariant(0));
 //	m_properties.insert("iEndAngle",TQVariant(360));
@@ -339,7 +339,7 @@ KviCanvasRectangle::KviCanvasRectangle(TQCanvas * c,int x,int y,int w,int h)
 	m_properties.insert("uLineWidth",TQVariant((unsigned int)0));
 
 	m_properties.insert("clrBackground",TQVariant(TQColor(0,0,0)));
-	m_properties.insert("bHasBackground",TQVariant(false,1));
+	m_properties.insert("bHasBackground",TQVariant(false));
 }
 
 KviCanvasRectangle::~KviCanvasRectangle()
@@ -1325,7 +1325,7 @@ void KviVariantTableItem::setContentFromEditor(TQWidget * w)
 			m_property = TQVariant(((TQLineEdit *)w)->text().toUInt());
 		break;
 		case TQVariant::Bool:
-			m_property = TQVariant(((TQComboBox *)w)->currentItem(),1);
+			m_property = TQVariant(((TQComboBox *)w)->currentItem());
 		break;
 		case TQVariant::Color:
 			m_property.asColor().setNamedColor(((TQLineEdit *)w)->text());
@@ -1440,7 +1440,7 @@ void KviCanvasItemPropertiesWidget::editItem(TQCanvasItem * it)
 		return;
 	}
 
-	TQMap<TQString,TQVariant> * m = 0;
+	TQStringVariantMap * m = 0;
 
 	switch(KVI_CANVAS_RTTI_CONTROL_TYPE(it))
 	{
@@ -1474,7 +1474,7 @@ void KviCanvasItemPropertiesWidget::editItem(TQCanvasItem * it)
 
 	int idx = 0;
 
-	for(TQMap<TQString,TQVariant>::ConstIterator iter = m->begin();iter != m->end();++iter)
+	for(TQStringVariantMap::ConstIterator iter = m->begin();iter != m->end();++iter)
 	{
 		item = new TQTableItem(this,TQTableItem::Never,iter.key().utf8().data());
 		setItem(idx,0,item);
