@@ -119,7 +119,7 @@ void KviCompletionBox::updateContents(TQString buffer)
 			if(szModule.isEmpty())
 				KviKvsKernel::instance()->completeFunction(buffer,&list);
 			else
-				debug("we need a module completion!");
+				tqDebug("we need a module completion!");
 			for ( TQString* szCurrent = list.first(); szCurrent; szCurrent = list.next() )
 			{
 				szCurrent->prepend('$');
@@ -133,19 +133,19 @@ void KviCompletionBox::updateContents(TQString buffer)
 		if(szModule.isEmpty())
 			KviKvsKernel::instance()->completeCommand(buffer,&list);
 		else
-			debug("we need a module completion!");
+			tqDebug("we need a module completion!");
 		for ( TQString* szCurrent = list.first(); szCurrent; szCurrent = list.next() )
 		{
 			szCurrent->append(' ');
 			insertItem(*szCurrent);
 		}
 	}
-//	debug("%s %s %i %i",__FILE__,__FUNCTION__,__LINE__,count());
+//	tqDebug("%s %s %i %i",__FILE__,__FUNCTION__,__LINE__,count());
 }
 
 void KviCompletionBox::keyPressEvent(TQKeyEvent * e)
 {
-//	debug("%s %s %i %x",__FILE__,__FUNCTION__,__LINE__,e->key());
+//	tqDebug("%s %s %i %x",__FILE__,__FUNCTION__,__LINE__,e->key());
 	switch(e->key())
 	{
 		case TQt::Key_Escape:
@@ -384,7 +384,7 @@ void KviScriptEditorWidget::keyPressEvent(TQKeyEvent * e)
 					insertAt(szCur,para,0);
 					setCursorPosition(para,szCur.length()+pos);
 				}
-//				debug("|%i|",pos);
+//				tqDebug("|%i|",pos);
 			}
 			return;
 		default:
@@ -423,7 +423,7 @@ void KviScriptEditorWidget::contentsMousePressEvent(TQMouseEvent *e)
 		if (l.count() != 1) buffer="";
 		else buffer=*(l.at(0));
 	}
-	//debug (buffer);
+	//tqDebug (buffer);
 	m_szHelp=buffer;
 	}
 	KviTalTextEdit::contentsMousePressEvent(e);
@@ -468,7 +468,7 @@ bool KviScriptEditorWidget::contextSensitiveHelp() const
 
 	TQString parse;
 	KviTQString::sprintf(parse,"timer -s (help,0){ help -s %Q; }",&buffer);
-	debug ("parsing %s",parse.latin1());
+	tqDebug ("parsing %s",parse.latin1());
 	KviKvsScript::run(parse,(KviWindow*)g_pApp->activeConsole());
 	
 	return true;
@@ -478,7 +478,7 @@ bool KviScriptEditorWidget::contextSensitiveHelp() const
 void KviScriptEditorWidget::getWordOnCursor(TQString &buffer,int index) const
 {
 	TQRegExp re("[ \t=,\\(\\)\"}{\\[\\]\r\n+-*><;@!]");
-	//debug("BUFFER IS %s",buffer.utf8().data());
+	//tqDebug("BUFFER IS %s",buffer.utf8().data());
 	int start = buffer.findRev(re,index);
 	int end = buffer.find(re,index);
 
@@ -491,7 +491,7 @@ void KviScriptEditorWidget::getWordOnCursor(TQString &buffer,int index) const
 		tmp = buffer.mid(start,end-start);
 	}
 	buffer = tmp;
-	//debug("BUFFER NOW IS %s",buffer.utf8().data());
+	//tqDebug("BUFFER NOW IS %s",buffer.utf8().data());
 }
 
 void KviScriptEditorWidget::completition(bool bCanComplete)
