@@ -853,9 +853,9 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
 			KviKvsVariant v;
 			v.setString(szTemp);
 			n->set(idx,new KviKvsVariant(v));
-			debug ("string %s",szTemp.latin1());
-			debug ("class %s",szClass.latin1());
-			debug ("Obj %s",szObj.latin1());
+			tqDebug ("string %s",szTemp.latin1());
+			tqDebug ("class %s",szClass.latin1());
+			tqDebug ("Obj %s",szObj.latin1());
 	
 			idx++;
 	
@@ -892,9 +892,9 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
 			KviKvsVariant v;
 			v.setString(szTemp);
 			n->set(idx,new KviKvsVariant(v));
-			debug ("string %s",szTemp.latin1());
-			debug ("class %s",szClass.latin1());
-			debug ("Obj %s",szObj.latin1());
+			tqDebug ("string %s",szTemp.latin1());
+			tqDebug ("class %s",szClass.latin1());
+			tqDebug ("Obj %s",szObj.latin1());
 	
 			idx++;
 	
@@ -935,7 +935,7 @@ static void dumpChildObjects(KviWindow *pWnd, TQObject *parent, const char *spac
 			KviKvsVariant v;
 			v.setString(szTemp);
 			n->set(idx,new KviKvsVariant(v));
-			debug ("string %s",szTemp.latin1());
+			tqDebug ("string %s",szTemp.latin1());
 			idx++;
 			dumpChildObjects(pWnd, list.at(i), sp, bFlag, n, idx );
 		}
@@ -965,7 +965,7 @@ static void dumpChildObjects(KviWindow *pWnd, TQObject *parent, const char *spac
 			KviKvsVariant v;
 			v.setString(szTemp);
 			n->set(idx,new KviKvsVariant(v));
-			debug ("string %s",szTemp.latin1());
+			tqDebug ("string %s",szTemp.latin1());
 			idx++;
 			dumpChildObjects(pWnd, it.current(), sp, bFlag, n, idx );
                 }
