@@ -71,7 +71,7 @@ KviThemeTransparencyOptionsWidget::KviThemeTransparencyOptionsWidget(TQWidget *
 			__tr2qs_ctx("<center>This option makes all KVIrc windows look " \
 				"transparent.<br>You must choose a blending " \
 				"background image to below or check the " \
-				"\"Use KDE desktop for transparency\" option.</center>","options"));
+				"\"Use TDE desktop for transparency\" option.</center>","options"));
 	#else
 		mergeTip(m_pUseTransparencyBoolSelector,
 			__tr2qs_ctx("<center>This option makes all KVIrc windows look " \
@@ -94,12 +94,12 @@ KviThemeTransparencyOptionsWidget::KviThemeTransparencyOptionsWidget(TQWidget *
 
 //	addRowSpacer(0,13,0,13);
 #ifdef COMPILE_TDE_SUPPORT
-	m_pObtainBackgroundFromKdeBoolSelector = addBoolSelector(0,4,1,4,__tr2qs_ctx("Use KDE desktop for transparency","options"),KviOption_boolObtainGlobalBackgroundFromKde,
+	m_pObtainBackgroundFromKdeBoolSelector = addBoolSelector(0,4,1,4,__tr2qs_ctx("Use TDE desktop for transparency","options"),KviOption_boolObtainGlobalBackgroundFromKde,
 				KVI_OPTION_BOOL(KviOption_boolUseGlobalPseudoTransparency));
 	connect(m_pUseTransparencyBoolSelector,TQT_SIGNAL(toggled(bool)),m_pObtainBackgroundFromKdeBoolSelector,TQT_SLOT(setEnabled(bool)));
 	connect(m_pObtainBackgroundFromKdeBoolSelector,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(enableUpdateKdeBackgroundBoolSelector(bool)));
 
-	m_pUpdateKdeBackgroundOnChangeBoolSelector = addBoolSelector(0,5,1,5,__tr2qs_ctx("Keep in sync with KDE background changes","options"),KviOption_boolUpdateKdeBackgroundOnChange,
+	m_pUpdateKdeBackgroundOnChangeBoolSelector = addBoolSelector(0,5,1,5,__tr2qs_ctx("Keep in sync with TDE background changes","options"),KviOption_boolUpdateKdeBackgroundOnChange,
 				KVI_OPTION_BOOL(KviOption_boolUseGlobalPseudoTransparency) && KVI_OPTION_BOOL(KviOption_boolObtainGlobalBackgroundFromKde));
 
 	m_pGlobalBackgroundPixmapSelector = addPixmapSelector(0,6,1,6,__tr2qs_ctx("Transparency blend image:","options"),KviOption_pixmapGlobalTransparencyBackground,
