@@ -862,7 +862,7 @@ void KviRegisteredUsersDialog::importClicked()
 
 			img = io.image();
 #endif
-			if(img.isNull())debug("Ops.. readed a null image ?");
+			if(img.isNull())tqDebug("Ops.. readed a null image ?");
 
 			KviStr fName = u->name();
 			kvi_encodeFileName(fName);
@@ -878,7 +878,7 @@ void KviRegisteredUsersDialog::importClicked()
 
 			if(!img.save(fPath.ptr(),"PNG"))
 			{
-				debug("Can't save image %s",fPath.ptr());
+				tqDebug("Can't save image %s",fPath.ptr());
 			} else {
 				u->setProperty("avatar",fPath.ptr());
 			}
